Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(416)

Unified Diff: samples/github/android/compile.sh

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: samples/github/android/compile.sh
diff --git a/samples/github/android/compile.sh b/samples/github/android/compile.sh
index 8f5cefc5cd7df3e9a83e2e49668cd2b35a682730..17b1ad034b0064504be802a87c01dc459db2f2bb 100755
--- a/samples/github/android/compile.sh
+++ b/samples/github/android/compile.sh
@@ -7,8 +7,8 @@
# Build steps
# - Run immic.
# - Run servicec.
# - Build fletch library generators for target platforms (here ia32 and arm).
# - In the servicec java output directory build libfletch using ndk-build.
# - Copy/link output files from immic and servicec to the jni and java directories.
# - Generate a snapshot of your Dart program and add it to you resources dir.
@@ -19,7 +19,7 @@ set -ue
DIR=$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)
-FLETCH_DIR="$(cd "$DIR/../../.." && pwd)"
+DARTINO_DIR="$(cd "$DIR/../../.." && pwd)"
# TODO(zerny): Support other modes than Release in tools/android_build/jni/Android.mk
TARGET_MODE=Release
@@ -30,17 +30,17 @@ TARGET_PKG_FILE="$TARGET_DIR/.packages"
IMMI_GEN_DIR="$TARGET_GEN_DIR/immi"
SERVICE_GEN_DIR="$TARGET_GEN_DIR/service"
-JAVA_DIR=$DIR/$ANDROID_PROJ/app/src/main/java/fletch
+JAVA_DIR=$DIR/$ANDROID_PROJ/app/src/main/java/dartino
JNI_LIBS_DIR=$DIR/$ANDROID_PROJ/app/src/main/jniLibs
-DART="$FLETCH_DIR/out/ReleaseIA32/dart"
-IMMIC="$DART $FLETCH_DIR/tools/immic/bin/immic.dart"
-FLETCH="$FLETCH_DIR/out/ReleaseIA32/fletch"
-SERVICEC="$FLETCH x-servicec"
+DART="$DARTINO_DIR/out/ReleaseIA32/dart"
+IMMIC="$DART $DARTINO_DIR/tools/immic/bin/immic.dart"
+DARTINO="$DARTINO_DIR/out/ReleaseIA32/dartino"
+SERVICEC="$DARTINO x-servicec"
set -x
-(cd $FLETCH_DIR; ninja -C out/ReleaseIA32)
+(cd $DARTINO_DIR; ninja -C out/ReleaseIA32)
# Generate dart service file and other immi files with the compiler.
if [[ $# -eq 0 ]] || [[ "$1" == "immi" ]]; then
@@ -55,21 +55,21 @@ if [[ $# -eq 0 ]] || [[ "$1" == "immi" ]]; then
# TODO(zerny): Change the servicec output directory structure to allow easy
# referencing from Android Studio.
mkdir -p $JAVA_DIR
- cp -R $SERVICE_GEN_DIR/java/fletch/*.java $JAVA_DIR/
+ cp -R $SERVICE_GEN_DIR/java/dartino/*.java $JAVA_DIR/
fi
# Build the native interpreter src for arm and x86.
-if [[ $# -eq 0 ]] || [[ "$1" == "fletch" ]]; then
- cd $FLETCH_DIR
+if [[ $# -eq 0 ]] || [[ "$1" == "dartino" ]]; then
+ cd $DARTINO_DIR
ninja
- ninja -C out/${TARGET_MODE}XARMAndroid fletch_vm_library_generator
- ninja -C out/${TARGET_MODE}IA32Android fletch_vm_library_generator
- mkdir -p out/${TARGET_MODE}XARMAndroid/obj/src/vm/fletch_vm.gen
- mkdir -p out/${TARGET_MODE}IA32Android/obj/src/vm/fletch_vm.gen
- out/${TARGET_MODE}XARMAndroid/fletch_vm_library_generator > \
- out/${TARGET_MODE}XARMAndroid/obj/src/vm/fletch_vm.gen/generated.S
- out/${TARGET_MODE}IA32Android/fletch_vm_library_generator > \
- out/${TARGET_MODE}IA32Android/obj/src/vm/fletch_vm.gen/generated.S
+ ninja -C out/${TARGET_MODE}XARMAndroid dartino_vm_library_generator
+ ninja -C out/${TARGET_MODE}IA32Android dartino_vm_library_generator
+ mkdir -p out/${TARGET_MODE}XARMAndroid/obj/src/vm/dartino_vm.gen
+ mkdir -p out/${TARGET_MODE}IA32Android/obj/src/vm/dartino_vm.gen
+ out/${TARGET_MODE}XARMAndroid/dartino_vm_library_generator > \
+ out/${TARGET_MODE}XARMAndroid/obj/src/vm/dartino_vm.gen/generated.S
+ out/${TARGET_MODE}IA32Android/dartino_vm_library_generator > \
+ out/${TARGET_MODE}IA32Android/obj/src/vm/dartino_vm.gen/generated.S
cd $SERVICE_GEN_DIR/java
CPUCOUNT=1
@@ -86,14 +86,14 @@ fi
if [[ $# -eq 0 ]] || [[ "$1" == "snapshot" ]]; then
# Kill the persistent process
- cd $FLETCH_DIR
+ cd $DARTINO_DIR
SNAPSHOT="$DIR/$ANDROID_PROJ/app/src/main/res/raw/${PROJ}_snapshot"
mkdir -p `dirname "$SNAPSHOT"`
$DART -c --packages=.packages \
-Dsnapshot="$SNAPSHOT" \
-Dpackages="$TARGET_PKG_FILE" \
- tests/fletchc/run.dart "$TARGET_DIR/bin/$PROJ.dart"
+ tests/dartino_compiler/run.dart "$TARGET_DIR/bin/$PROJ.dart"
fi
set +x
@@ -101,6 +101,6 @@ set +x
if [[ $# -eq 1 ]]; then
echo
echo "Only ran task $1."
- echo "Possible tasks: immi, fletch, and snapshot"
- echo "If Fletch or any IMMI files changed re-run compile.sh without arguments."
+ echo "Possible tasks: immi, dartino, and snapshot"
+ echo "If Dartino or any IMMI files changed re-run compile.sh without arguments."
fi
« no previous file with comments | « samples/github/android/GithubSample/app/src/main/res/layout/cards_layout.xml ('k') | samples/github/android/compile_mock.sh » ('j') | no next file with comments »
@@ -7,8 +7,8 @@
# - Run immic.
# - Run servicec.
-# - Build fletch library generators for target platforms (here ia32 and arm).
-# - In the servicec java output directory build libfletch using ndk-build.
+# - Build dartino library generators for target platforms (here ia32 and arm).
+# - In the servicec java output directory build libdartino using ndk-build.
# - Copy/link output files from immic and servicec to the jni and java directories.
# - Generate a snapshot of your Dart program and add it to you resources dir.

Powered by Google App Engine
This is Rietveld 408576698